@@ -11,7 +11,7 @@
 
    being removed.
 
-   Copyright (C) 2004-2019 by Brian Lindholm.  This file is part of the
+   Copyright (C) 2004-2020 by Brian Lindholm.  This file is part of the
    littleutils utility set.
 
    The pngstrip utility is free software; you can redistribute it and/or modify
@@ -28,27 +28,29 @@
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
 
-#include "../config.h"
-#include <stdio.h>
-#include <stdlib.h>
+#include <config.h>
 
+#include <stdio.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+
+#ifdef HAVE_GETOPT_H
+# include <getopt.h>
+#endif
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
+# include <unistd.h>
+# define OPTEND -1
 #else
-#define OPTEND EOF
+# define OPTEND EOF
 #endif
 
 #ifdef HAVE_ZLIB_H
-#include <zlib.h>
+# include <zlib.h>
 #endif
 
 #include <png.h>
 
-#ifdef HAVE_GETOPT_H
-#include <getopt.h>
-#endif
-
 #ifdef __MINGW32__
 extern int getopt (int argc, char * const *argv, const char *optstring);
 extern char *optarg;
@@ -56,7 +58,7 @@ extern int optind;
 #endif
 
 #ifndef PNG_TRANSFORM_GRAYSCALE
-#define PNG_TRANSFORM_GRAYSCALE 0x1000 /* on reads only */
+# define PNG_TRANSFORM_GRAYSCALE 0x1000 /* on reads only */
 #endif
 
 
