@@ -1,6 +1,6 @@
 /* filedate:  Prints out the modification time for the specified files.
 
-   Copyright (C) 2004-2013 by Brian Lindholm.
+   Copyright (C) 2004-2020 by Brian Lindholm.
    This file is part of the littleutils utility set.
 
    The filedate utility is free software; you can redistribute it and/or modify
@@ -17,22 +17,27 @@
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
 
-#include "../config.h"
+#include <config.h>
+
 #include <limits.h>
 #include <stdio.h>
-#include <string.h>
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
 #include <time.h>
-#include <sys/stat.h>
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
+#endif
 
 #ifdef HAVE_GETOPT_H
-#include <getopt.h>
+# include <getopt.h>
 #endif
 
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
+# include <unistd.h>
+# define OPTEND -1
 #else
-#define OPTEND EOF
+# define OPTEND EOF
 #endif
 
 #ifdef __MINGW32__
@@ -47,7 +52,7 @@ unsigned short _djstat_flags = 63;
 #endif
 
 #ifndef PATH_MAX
-#define PATH_MAX 256
+# define PATH_MAX 256
 #endif
 
 #define FORMAT_DEFAULT 0
