@@ -28,8 +28,9 @@ SHA384='n'
 SHA512='n'
 B2_256='n'
 B2_512='n'
-BYTES='all'
-while getopts 12345678chn: opts
+COUNT=''
+SKIP=''
+while getopts 12345678chn:o: opts
 do
   case $opts in
     1) MD5=y ;;
@@ -43,20 +44,21 @@ do
     h) echo 'filehash LU_VERSION'
        echo 'usage: filehash [-1(MD5)] [-2(SHA1)] [-3(SHA224)] [-4(SHA256)]'
        echo '         [-5(SHA384)] [-6(SHA512)] [-7(BLAKE2B_256)] [-8(BLAKE2B_256)]'
-       echo '         [-h(elp)] [-n byte_count] file...'
+       echo '         [-h(elp)] [-n byte_count] [-o byte_offset] file...'
        exit 0 ;;
-    n) BYTES="$OPTARG" ;;
+    n) COUNT="count=$OPTARG" ;;
+    o) SKIP="skip=$OPTARG" ;;
     *) echo 'filehash LU_VERSION'
        echo 'usage: filehash [-1(MD5)] [-2(SHA1)] [-3(SHA224)] [-4(SHA256)]'
        echo '         [-5(SHA384)] [-6(SHA512)] [-7(BLAKE2B_256)] [-8(BLAKE2B_256)]'
-       echo '         [-h(elp)] [-n byte_count] file...'
+       echo '         [-h(elp)] [-n byte_count] [-o byte_offset] file...'
        exit 1 ;;
   esac
 done
 shift `expr ${OPTIND} - 1`
 
 # compute hashes as requested
-if [ "$BYTES" = 'all' ]; then
+if [ "X$COUNT" = 'X' -a "X$SKIP" = 'X' ]; then
   for IDX in "$@" ; do
     if [ "$MD5" = 'y' ]; then md5sum $IDX ; fi
     if [ "$SHA1" = 'y' ]; then sha1sum $IDX ; fi
@@ -69,13 +71,13 @@ if [ "$BYTES" = 'all' ]; then
   done
 else
   for IDX in "$@" ; do
-    if [ "$MD5" = 'y' ]; then dd status=none if=$IDX bs=1 count="$BYTES" | md5sum | sed -e "s/-$/$IDX/" ; fi
-    if [ "$SHA1" = 'y' ]; then dd status=none if=$IDX bs=1 count="$BYTES" | sha1sum | sed -e "s/-$/$IDX/" ; fi
-    if [ "$SHA224" = 'y' ]; then dd status=none if=$IDX bs=1 count="$BYTES" | sha224sum | sed -e "s/-$/$IDX/" ; fi
-    if [ "$SHA256" = 'y' ]; then dd status=none if=$IDX bs=1 count="$BYTES" | sha256sum | sed -e "s/-$/$IDX/" ; fi
-    if [ "$SHA384" = 'y' ]; then dd status=none if=$IDX bs=1 count="$BYTES" | sha384sum | sed -e "s/-$/$IDX/" ; fi
-    if [ "$SHA512" = 'y' ]; then dd status=none if=$IDX bs=1 count="$BYTES" | sha512sum | sed -e "s/-$/$IDX/" ; fi
-    if [ "$B2_256" = 'y' ]; then dd status=none if=$IDX bs=1 count="$BYTES" | b2sum -l 256 | sed -e "s/-$/$IDX/" ; fi
-    if [ "$B2_512" = 'y' ]; then dd status=none if=$IDX bs=1 count="$BYTES" | b2sum -l 512 | sed -e "s/-$/$IDX/" ; fi
+    if [ "$MD5" = 'y' ]; then dd status=none if=$IDX bs=1 $COUNT $SKIP | md5sum | sed -e "s/-$/$IDX/" ; fi
+    if [ "$SHA1" = 'y' ]; then dd status=none if=$IDX bs=1 $COUNT $SKIP | sha1sum | sed -e "s/-$/$IDX/" ; fi
+    if [ "$SHA224" = 'y' ]; then dd status=none if=$IDX bs=1 $COUNT $SKIP | sha224sum | sed -e "s/-$/$IDX/" ; fi
+    if [ "$SHA256" = 'y' ]; then dd status=none if=$IDX bs=1 $COUNT $SKIP | sha256sum | sed -e "s/-$/$IDX/" ; fi
+    if [ "$SHA384" = 'y' ]; then dd status=none if=$IDX bs=1 $COUNT $SKIP | sha384sum | sed -e "s/-$/$IDX/" ; fi
+    if [ "$SHA512" = 'y' ]; then dd status=none if=$IDX bs=1 $COUNT $SKIP | sha512sum | sed -e "s/-$/$IDX/" ; fi
+    if [ "$B2_256" = 'y' ]; then dd status=none if=$IDX bs=1 $COUNT $SKIP | b2sum -l 256 | sed -e "s/-$/$IDX/" ; fi
+    if [ "$B2_512" = 'y' ]; then dd status=none if=$IDX bs=1 $COUNT $SKIP | b2sum -l 512 | sed -e "s/-$/$IDX/" ; fi
   done
 fi
