@@ -30,20 +30,27 @@ char /*-------------------------------------------------------------------+
 *
 +------------------------------------------------------------------------*/
 
-#include "../config.h"
+#include <config.h>
+
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <strings.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
+#ifdef HAVE_STRINGS_H
+# include <strings.h>
+#endif
 #include <ctype.h>
-#include <sys/stat.h>
-
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
+#endif
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+# include <unistd.h>
 #endif
-
 #ifdef HAVE_LIBINTL_H
-#include <libintl.h>
+# include <libintl.h>
 #endif
 
 #define NO 0
